MethodChannelFlutterUsbThermalPlugin class

An implementation of FlutterUsbThermalPluginPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<bool?>
close close the connection after print with usb printer
override
connect(int vendorId, int productId) → Future<bool?>
connect connect to a printer vai vendorId and productId
override
getPlatformVersion() → Future<String?>
override
getUSBDeviceList() → Future<List<Map<String, dynamic>>>
getUSBDeviceList get list of available usb device on android
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printRawText(String text) → Future<bool?>
printRawText print raw text
override
printText(String text) → Future<bool?>
printText print text
override
toString() → String
A string representation of this object.
inherited
write(Uint8List data) → Future<bool?>
write write data byte
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited